@@ -66,9 +66,8 @@ my sub _mail_passw_login ($job, $to_user, $domain) {
   $app->minion->enqueue(
     delete_passw_login => [$to_user->{id}, $token] => {delay => $CONF->{token_valid_for}}
   );
-  $job->finish('Писмото с временен ключ за влизане в '
-      . $domain
-      . ' до '
+  return $job->finish('Писмото с временен ключ за влизане в '
+      . $domain . ' до '
       . $to_user->{first_name} . ' '
       . $to_user->{last_name}
       . ' бе успешно изпратено!');
@@ -81,7 +80,7 @@ my sub _delete_passw_login ($job, $uid, $token) {
 
   # also delete expired but not deleted (for any reason) login tokens.
   $app->dbx->db->delete('passw_login' => {stop_date => {'<' => time}});
-  $job->finish;
+  return $job->finish;
 };
 
 
