@@ -557,5 +557,26 @@ CREATE INDEX first_login_stop_date ON first_login(stop_date);
 DROP INDEX IF EXISTS first_login_stop_date;
 DROP TABLE IF EXISTS first_login;
 
+-- 201812222222 up
+CREATE table passw_login (
+  id INTEGER PRIMARY KEY AUTOINCREMENT,
+  -- sha1_sum generated by minion task mail_passw_login
+  token VARCHAR(40) UNIQUE,
+  -- User for which this login token is valid
+  to_uid INTEGER REFERENCES users(id),
+  -- timestamp before which this login token is not yet valid.
+  start_date INTEGER DEFAULT 9543310605,
+  -- timestam after which this login token is no more valid.
+  stop_date INTEGER DEFAULT 1
+);
+
+CREATE INDEX passw_login_stop_date ON passw_login(stop_date);
+CREATE INDEX passw_login_to_uid ON passw_login(to_uid);
+
+-- 201812222222 down
+DROP INDEX IF EXISTS passw_login_stop_date;
+DROP INDEX IF EXISTS passw_login_to_uid;
+DROP TABLE IF EXISTS passw_login;
+
 
 
