@@ -3,19 +3,20 @@ jQuery(function($) {
     'use strict';
     let Editors = {
         $selector: 'textarea[name="body"]',
+        $body_id: '_body',
         // A simple textarea
         text: function() {
             let $body = this.$selector;
             //get the value to keep it
             let $value = $($body).val();
             //empty the container
-            $('#_body').empty();
+            $('#'+this.$body_id).empty();
             // recreate the textarea
-            $('#_body').append(`<textarea name="body" required
+            $('#'+this.$body_id).append(`<textarea name="body" required
             style="width:100%;height:25em"></textarea>`);
             $($body).val($value);
         },
-        //Apply a html editor to the textareaea
+        //Apply a html editori to the textareaea
         html: function() {
             this.text();
             $(this.$selector).trumbowyg({
@@ -36,6 +37,25 @@ jQuery(function($) {
                 removeformatPasted: true,
                 lang: 'bg'
             });
+        },
+        markdown: function() {
+            this.text();
+            let editor_body = $(`#${this.$body_id}`);
+            let height = editor_body.css('height');
+            let editor = editormd(this.$body_id, {
+                width  : 'auto',
+                watch: false,
+                toolbarIcons: [
+                    "undo", "redo", "|", "bold", "del", "italic", "quote", "uppercase",
+                    "lowercase", "|", "h1", "h2", "h3", "h4", "h5", "h6", "|",
+                    "list-ul", "list-ol", "hr", "|", "link", "reference-link", "image",
+                    "code", "code-block", "table",
+                    "watch", "preview", "fullscreen", "|", "help", "info"
+        ],
+                path    : '/js/editormd/lib/'
+            });
+            editor.editor.css({position: 'relaive', top: '1rem'})
+            editor.editor.height(height)
         }
     }; // End Editors
 
